@@ -1,7 +1,6 @@
 from fairies.read import (
     read,
     read_json,
-    read_txt,
     read_npy
 )
 
@@ -63,11 +62,12 @@ from navinfo_tool.utils import (
     rm_bracketed,    # 去除文本中的括号，包括括号中的内容
     rm_symbol,    # 去除文本中的所有符号
     getLCS,    # 获取最长公共序列
+    write_json,  # 将json数据写到json文件中，解决了一些数据类型报错问题
     read_csv,    # 读取csv文件， 可以返回为list或者dict，通过isdict=True设置
     write_csv,  # 将数组的内容写到csv中, 支持list或者dict两种数据格式
     read_excel,    # 读取excel文件，可以返回为list或者dict，通过isdict=True设置
-    write_json,    # 将json数据写到json文件中，解决了一些数据类型报错问题
     write_excel,    # 将数组的内容写到excel中, 支持list或者dict两种数据格式
+    read_txt,       # 读取txt文件，按行作为元素
     compute_vecsimilar_one_2_one,    # 计算两个向量的相似度，需要维度相同
     compute_vecsimilar__one_2_many,    # 计算一个向量和多个向量的相似度，返回相似度最大的下标和对应的相似度
     compute_vecsimilar__many_2_many    # 计算多个向量和多个向量的相似度，返回第一个参数中每个相似度最大的下标和对应的相似度
